Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Migration Hub Strategy Recommendations..

Actions, resources, and condition keys for AWS Migration Hub Strategy Recommendations. - Service Authorization Reference

# Actions, resources, and condition keys for AWS Migration Hub Strategy Recommendations.

AWS Migration Hub Strategy Recommendations. (service prefix: `migrationhub-strategy` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Migration Hub Strategy Recommendations.
- Resource types defined by AWS Migration Hub Strategy Recommendations.
- Condition keys for AWS Migration Hub Strategy Recommendations.

## Actions defined by AWS Migration Hub Strategy Recommendations.

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
GetAntiPattern | Grants permission to get details of each anti pattern that collector should look at in a customer's environment | Read |  |  |
GetApplicationComponentDetails | Grants permission to get details of an application | Read |  |  |
GetApplicationComponentStrategies | Grants permission to get a list of all recommended strategies and tools for an application running in a server | Read |  |  |
GetAssessment | Grants permission to retrieve status of an on-going assessment | Read |  |  |
GetImportFileTask | Grants permission to get details of a specific import task | Read |  |  |
GetMessage | Grants permission to the collector to receive information from the service | Read |  |  |
GetPortfolioPreferences | Grants permission to retrieve customer migration/Modernization preferences | Read |  |  |
GetPortfolioSummary | Grants permission to retrieve overall summary (number-of servers to rehost etc as well as overall number of anti patterns) | Read |  |  |
GetRecommendationReportDetails | Grants permission to retrieve detailed information about a recommendation report | Read |  |  |
GetServerDetails | Grants permission to get info about a specific server | Read |  |  |
GetServerStrategies | Grants permission to get recommended strategies and tools for a specific server | Read |  |  |
ListAntiPatterns | Grants permission to get a list of all anti patterns that collector should look for in a customer's environment | List |  |  |
ListApplicationComponents | Grants permission to get a list of all applications running on servers on customer's servers | List |  |  |
ListCollectors | Grants permission to get a list of all collectors installed by the customer | List |  |  |
ListImportFileTask | Grants permission to get list of all imports performed by the customer | List |  |  |
ListJarArtifacts | Grants permission to get a list of binaries that collector should assess | List |  |  |
ListServers | Grants permission to get a list of all servers in a customer's environment | List |  |  |
PutPortfolioPreferences | Grants permission to save customer's Migration/Modernization preferences | Write |  |  |
RegisterCollector | Grants permission to register the collector to receive an ID and to start receiving messages from the service | Write |  |  |
SendMessage | Grants permission to the collector to send information to the service | Write |  |  |
StartAssessment | Grants permission to start assessment in a customer's environment (collect data from all servers and provide recommendations) | Write |  |  |
StartImportFileTask | Grants permission to start importing data from a file provided by customer | Write |  |  |
StartRecommendationReportGeneration | Grants permission to start generating a recommendation report | Write |  |  |
StopAssessment | Grants permission to stop an on-going assessment | Write |  |  |
UpdateApplicationComponentConfig | Grants permission to update details for an application | Write |  |  |
UpdateServerConfig | Grants permission to update info on a server along with the recommended strategy | Write |  |  |

## Resource types defined by AWS Migration Hub Strategy Recommendations.

AWS Migration Hub Strategy Recommendations. does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Migration Hub Strategy Recommendations., specify `“Resource”: “*”` in your policy.

## Condition keys for AWS Migration Hub Strategy Recommendations.

Migration Hub Strategy Recommendations has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.